struct_layout

Function struct_layout 

pub fn struct_layout(
    fields: &[(Arc<str>, LayoutId)],
    layouts: &[Layout],
) -> (Vec<Field>, Vec<Repr>)
Lays out a struct’s fields, answering the fields and the flattened words.

Fields are placed in declaration order with no padding: a word is a word and there is nothing to align.